View source: R/chilling_units.R
| chilling_units | R Documentation |
Function to calculate winter chill for deciduous trees according to the Chilling Units model proposed by
Harrington et al. (2010). This function is compatible with some chillR functions
(i.e tempResponse) to estimate metrics from hourly temperature records.
chilling_units(HourTemp, summ = TRUE)
HourTemp |
Vector of hourly temperatures |
summ |
Boolean parameter indicating whether the computed metric should be provided as cumulative values over the period or as the actual accumulation for each hour |
Harrington C., Gould P. and St.Clair J. (2010). Modeling the effects of winter environment on dormancy release of Douglas-fir. For. Ecol. Manage. 259(4): 798-808. https://doi.org/10.1016/j.foreco.2009.06.018
library(chillR) #Example 1 data <- stack_hourly_temps(KA_weather, latitude = 50.62) chilling_units(data$hourtemps$Temp, summ = TRUE) #Example 2 tempResponse(data, Start_JDay = 345, End_JDay = 58, models = list(Chill_Harrington = chilling_units))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.