View source: R/modified_utah_model.R
| modified_utah_model | R Documentation |
Function to calculate winter chill for deciduous trees according to the Modified Utah model proposed by
Linvill (1990). This function is compatible with some chillR functions
(i.e tempResponse) to
estimate metrics from hourly temperature records.
modified_utah_model(HourTemp, summ = TRUE)
HourTemp |
Vector of hourly temperatures |
summ |
Boolean parameter indicating whether the computed metric should be provided as cumulative values over the period or as the actual accumulation for each hour |
Linvill D. 1990. Calculating chilling hours and chill units from daily maximum and minimum temperature observations. HortScience 25(1): 14-16. https://doi.org/10.21273/HORTSCI.25.1.14
library(chillR)
#Example 1
data <- stack_hourly_temps(KA_weather, latitude = 50.62)
modified_utah_model(data$hourtemps$Temp, summ = TRUE)
#Example 2
tempResponse(data, Start_JDay = 345, End_JDay = 58,
models = list(Modified_Units = modified_utah_model))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.